@@ -15,22 +15,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
-import json
 import os
 from oslo_config import cfg
 import oslo_messaging
+from oslo_serialization import jsonutils
+import six.moves.urllib.parse as urlparse
 import sys
 import time
 
-
-try:
-    import urlparse as urlparse
-except ImportError:
-    import urllib.parse as urlparse
-
-
-topic = 'searchlight_indexer'
+topic = 'notifications'
 password = os.environ.get('RABBIT_PASSWORD', os.environ.get('OS_PASSWORD'))
 host = urlparse.urlparse(os.environ.get('OS_AUTH_URL')).hostname
 username = os.environ.get('RABBIT_USER', 'stackrabbit')
@@ -40,12 +33,12 @@ class EP(object):
     def info(self, ctxt, publisher_id, event_type, payload, metadata):
         all_locals = locals()
         all_locals.pop('self')
-        print(json.dumps(all_locals))
+        print(jsonutils.dumps(all_locals))
 
     def error(self, ctxt, publisher_id, event_type, payload, metadata):
         all_locals = locals()
         all_locals.pop('self')
-        print(json.dumps(all_locals))
+        print(jsonutils.dumps(all_locals))
 
 
 def main():
@@ -56,7 +49,7 @@ def main():
     exchange = sys.argv[1]
     pool = sys.argv[2] if len(sys.argv) > 2 else None
 
-    transport = oslo_messaging.get_transport(
+    transport = oslo_messaging.get_notification_transport(
         cfg.CONF,
         url='rabbit://%s:%s@%s' % (username, password, host))
     targets = [oslo_messaging.Target(topic=topic, exchange=exchange)]
